# CulebrONT {.unnumbered}

Congratulations! You have successfully ran CulebrONT and now enjoy results through this nice report!

CulebrONT is a Snakemake workflow available on [gitlab](https://forge.ird.fr/diade/culebront_pipeline)

Licenced under [CeCill-C](http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html) and [GPLv3](https://www.gnu.org/licenses/gpl-3.0.en.html).

Intellectual property belongs to authors.

Please don't forget to cite us @culebront.

